@@ -246,15 +246,15 @@ namespace FaustUtilities_MODEL {
 
 		private IntPtr _context;
 
-        #if UNITY_EDITOR_OSX || UNITY_EDITOR_WIN || UNITY_STANDALONE_OSX || UNITY_STANDALONE_WIN || UNITY_WSA || UNITY_WSA_10_0
-        const string _dllName = "PLUGNAME";
-        #elif UNITY_IOS
-        const string _dllName = "__Internal";
-        #elif UNITY_EDITOR || UNITY_ANDROID || UNITY_STANDALONE_LINUX
-        const string _dllName = "PLUGINNAME";
-        #else
-        Debug.LogError("Architecture not supported by the plugin");
-        #endif
+		#if UNITY_EDITOR_OSX || UNITY_EDITOR_WIN || UNITY_STANDALONE_OSX || UNITY_STANDALONE_WIN || UNITY_WSA || UNITY_WSA_10_0
+		const string _dllName = "PLUGNAME";
+		#elif UNITY_IOS
+		const string _dllName = "__Internal";
+		#elif UNITY_EDITOR || UNITY_ANDROID || UNITY_STANDALONE_LINUX
+		const string _dllName = "PLUGINNAME";
+		#else
+		Debug.LogError("Architecture not supported by the plugin");
+		#endif
 
 		// Imports all c++ function to intialize and process the dsp. The methods need to be private
 		[DllImport(_dllName)]
@@ -539,11 +539,21 @@ namespace FaustUtilities_MODEL {
 										uiItems[numItems].label = value.ToString();
 									}
 									break;
+								case "shortname":
+									if (parseChar(ref s, ':') && parseDQString(ref s, out value)) {
+										uiItems[numItems].shortname = value.ToString();
+									}
+									break;
 								case "address":
 									if (parseChar(ref s, ':') && parseDQString(ref s, out value)) {
 										uiItems[numItems].address = value.ToString();
 									}
 									break;
+								case "url":
+									if (parseChar(ref s, ':') && parseDQString(ref s, out value)) {
+										uiItems[numItems].url = value.ToString();
+									}
+									break;
 								case "meta":
 									uiItems[numItems].meta = new List < Meta > ();
 									if (!parseItemMetaData(ref s, uiItems[numItems].meta)) {
@@ -587,8 +597,6 @@ namespace FaustUtilities_MODEL {
 							}
 						} while (parseChar(ref s , ','));
 						parseChar(ref s, '}');
-					} else {
-						return false;
 					}
 				} while (parseChar(ref s , ','));
 				return parseChar(ref s, ']');
@@ -603,9 +611,11 @@ namespace FaustUtilities_MODEL {
 	public class Group {
 		public string type;
 		public string label;
+		public string shortname;
+		public string address;
+		public string url;
 		public List < Meta > meta;
 		public List < Group > items;
-		public string address;
 		public float init;
 		public float min;
 		public float max;
