@@ -27,6 +27,7 @@
 #include <sstream>
 
 #include "Text.hh"
+#include "sha_key.hh"
 #include "compatibility.hh"
 #include "dsp_aux.hh"
 #include "dsp_factory.hh"
@@ -209,9 +210,15 @@ string reorganizeCompilationOptions(int argc, const char* argv[])
     return quote(res3);
 }
 
+string sha1FromDSP(const string& name_app, const string& dsp_content, int argc, const char* argv[], string& sha_key)
+{
+    sha_key = generateSHA1(name_app + dsp_content + reorganizeCompilationOptions(argc, argv));
+    return dsp_content;
+}
+
 // External C++ libfaust API
 
-EXPORT string expandDSPFromFile(const string& filename, int argc, const char* argv[], string& sha_key,
+LIBFAUST_API string expandDSPFromFile(const string& filename, int argc, const char* argv[], string& sha_key,
                                 string& error_msg)
 {
     string base = basename((char*)filename.c_str());
@@ -222,7 +229,7 @@ EXPORT string expandDSPFromFile(const string& filename, int argc, const char* ar
 /*
 Same DSP code and same normalized compilation options will generate the same SHA key.
 */
-EXPORT string expandDSPFromString(const string& name_app, const string& dsp_content, int argc, const char* argv[],
+LIBFAUST_API string expandDSPFromString(const string& name_app, const string& dsp_content, int argc, const char* argv[],
                                   string& sha_key, string& error_msg)
 {
     LOCK_API
@@ -236,8 +243,8 @@ EXPORT string expandDSPFromString(const string& name_app, const string& dsp_cont
             sha_key = generateSHA1(dsp_content);
             return dsp_content;
         } else {
-            // Otherwise add a new compilation options line, consider it as the new expanded code : generate SHA key and
-            // return it
+            // Otherwise add a new compilation options line, consider it as the new expanded code,
+            // generate SHA key and return it
             string new_dsp_content =
                 COMPILATION_OPTIONS + reorganizeCompilationOptions(argc, argv) + ";\n" + dsp_content;
             sha_key = generateSHA1(new_dsp_content);
@@ -257,14 +264,14 @@ EXPORT string expandDSPFromString(const string& name_app, const string& dsp_cont
     }
 }
 
-EXPORT bool generateAuxFilesFromFile(const string& filename, int argc, const char* argv[], string& error_msg)
+LIBFAUST_API bool generateAuxFilesFromFile(const string& filename, int argc, const char* argv[], string& error_msg)
 {
     string base = basename((char*)filename.c_str());
     size_t pos  = filename.find(".dsp");
     return generateAuxFilesFromString(base.substr(0, pos), pathToContent(filename), argc, argv, error_msg);
 }
 
-EXPORT bool generateAuxFilesFromString(const string& name_app, const string& dsp_content, int argc, const char* argv[],
+LIBFAUST_API bool generateAuxFilesFromString(const string& name_app, const string& dsp_content, int argc, const char* argv[],
                                        string& error_msg)
 {
     LOCK_API
@@ -283,27 +290,20 @@ EXPORT bool generateAuxFilesFromString(const string& name_app, const string& dsp
         }
         argv1[argc1] = nullptr;  // NULL terminated argv
 
-        dsp_factory_base* factory =
-            compileFaustFactory(argc1, argv1, name_app.c_str(), dsp_content.c_str(), error_msg, false);
+        dsp_factory_base* factory = createFactory(name_app.c_str(), dsp_content.c_str(), argc1, argv1, error_msg, false);
         // Factory is no more needed
         delete factory;
         return (factory != nullptr);
     }
 }
 
-string sha1FromDSP(const string& name_app, const string& dsp_content, int argc, const char* argv[], string& sha_key)
-{
-    sha_key = generateSHA1(name_app + dsp_content + reorganizeCompilationOptions(argc, argv));
-    return dsp_content;
-}
-
 // External C libfaust API
 
 #ifdef __cplusplus
 extern "C" {
 #endif
     
-EXPORT const char* expandCDSPFromFile(const char* filename, int argc, const char* argv[], char* sha_key,
+LIBFAUST_API const char* expandCDSPFromFile(const char* filename, int argc, const char* argv[], char* sha_key,
                                       char* error_msg)
 {
     string sha_key_aux;
@@ -314,7 +314,7 @@ EXPORT const char* expandCDSPFromFile(const char* filename, int argc, const char
     return strdup(res.c_str());
 }
 
-EXPORT const char* expandCDSPFromString(const char* name_app, const char* dsp_content, int argc, const char* argv[],
+LIBFAUST_API const char* expandCDSPFromString(const char* name_app, const char* dsp_content, int argc, const char* argv[],
                                         char* sha_key, char* error_msg)
 {
     string sha_key_aux;
@@ -325,7 +325,7 @@ EXPORT const char* expandCDSPFromString(const char* name_app, const char* dsp_co
     return strdup(res.c_str());
 }
 
-EXPORT bool generateCAuxFilesFromFile(const char* filename, int argc, const char* argv[], char* error_msg)
+LIBFAUST_API bool generateCAuxFilesFromFile(const char* filename, int argc, const char* argv[], char* error_msg)
 {
     string error_msg_aux;
     bool   res = generateAuxFilesFromFile(filename, argc, argv, error_msg_aux);
@@ -333,7 +333,7 @@ EXPORT bool generateCAuxFilesFromFile(const char* filename, int argc, const char
     return res;
 }
 
-EXPORT bool generateCAuxFilesFromString(const char* name_app, const char* dsp_content, int argc, const char* argv[],
+LIBFAUST_API bool generateCAuxFilesFromString(const char* name_app, const char* dsp_content, int argc, const char* argv[],
                                         char* error_msg)
 {
     string error_msg_aux;
@@ -342,12 +342,7 @@ EXPORT bool generateCAuxFilesFromString(const char* name_app, const char* dsp_co
     return res;
 }
 
-EXPORT void generateCSHA1(const char* data, char* sha_key)
-{
-    strncpy(sha_key, generateSHA1(data).c_str(), 64);
-}
-
-EXPORT void freeCMemory(void* ptr)
+LIBFAUST_API void freeCMemory(void* ptr)
 {
     free(ptr);
 }
