@@ -87,6 +87,10 @@
 #include "dlang_code_container.hh"
 #endif
 
+#ifdef JULIA_BUILD
+#include "julia_code_container.hh"
+#endif
+
 // Parser
 extern FILE*       yyin;
 extern const char* yyfilename;
@@ -151,6 +155,7 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     gDSPStruct  = false;
     gLightMode  = false;
     gClang      = false;
+    gNoVirtual  = false;
     gCheckTable = "";
     
     gMathExceptions = false;
@@ -245,6 +250,8 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     gErrorCount = 0;
 
     gFileNum = 0;
+    
+    gExpCounter = 0;
 
     gCountInferences = 0;
     gCountMaximal    = 0;
@@ -260,7 +267,7 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     gOccurrences = nullptr;
     gFoldingFlag = false;
     gDevSuffix   = nullptr;
-
+   
     gAbsPrim       = new AbsPrim();
     gAcosPrim      = new AcosPrim();
     gTanPrim       = new TanPrim();
@@ -358,7 +365,6 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     SIGDELAY1          = symbol("SigDelay1");
     SIGDELAY           = symbol("SigDelay");
     SIGPREFIX          = symbol("SigPrefix");
-    SIGIOTA            = symbol("SigIota");
     SIGRDTBL           = symbol("SigRDTbl");
     SIGWRTBL           = symbol("SigWRTbl");
     SIGTABLE           = symbol("SigTable");
@@ -407,11 +413,13 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     SYMRECREF = symbol("SYMRECREF");
     SYMLIFTN  = symbol("LIFTN");
 
-    gMachineFloatSize  = sizeof(float);
-    gMachineInt32Size  = sizeof(int);
-    gMachineInt64Size  = sizeof(long int);
-    gMachineDoubleSize = sizeof(double);
-    gMachineBoolSize   = sizeof(bool);
+    gMachineFloatSize      = sizeof(float);
+    gMachineInt32Size      = sizeof(int);
+    gMachineInt64Size      = sizeof(long int);
+    gMachineDoubleSize     = sizeof(double);
+    gMachineQuadSize       = sizeof(long double);
+    gMachineFixedPointSize = gMachineFloatSize;
+    gMachineBoolSize       = sizeof(bool);
 
     // Assuming we are compiling for a 64 bits machine
     gMachinePtrSize = sizeof(nullptr);
@@ -452,6 +460,9 @@ global::global() : TABBER(1), gLoopDetector(1024, 400), gStackOverflowDetector(M
     gDrawSVGSwitch    = false;
     gVHDLSwitch       = false;
     gVHDLTrace        = false;
+    gVHDLFloatType    = 0; //sfixed
+    gVHDLFloatMSB     = 8;
+    gVHDLFloatLSB     = -23;
     gElementarySwitch = false;
     gPrintXMLSwitch   = false;
     gPrintJSONSwitch  = false;
@@ -565,11 +576,13 @@ void global::init()
     // Create type declaration for external 'soundfile' type
     vector<NamedTyped*> sf_type_fields;
     sf_type_fields.push_back(
-        InstBuilder::genNamedTyped("fBuffers", InstBuilder::genBasicTyped(Typed::kFloatMacro_ptr_ptr)));
+        InstBuilder::genNamedTyped("fBuffers", InstBuilder::genBasicTyped(Typed::kVoid_ptr)));
     sf_type_fields.push_back(InstBuilder::genNamedTyped("fLength", InstBuilder::genBasicTyped(Typed::kInt32_ptr)));
     sf_type_fields.push_back(InstBuilder::genNamedTyped("fSR", InstBuilder::genBasicTyped(Typed::kInt32_ptr)));
     sf_type_fields.push_back(InstBuilder::genNamedTyped("fOffset", InstBuilder::genBasicTyped(Typed::kInt32_ptr)));
     sf_type_fields.push_back(InstBuilder::genNamedTyped("fChannels", InstBuilder::genInt32Typed()));
+    sf_type_fields.push_back(InstBuilder::genNamedTyped("fParts", InstBuilder::genInt32Typed()));
+    sf_type_fields.push_back(InstBuilder::genNamedTyped("fIsDouble", InstBuilder::genInt32Typed()));
     gExternalStructTypes[Typed::kSound] =
         InstBuilder::genDeclareStructTypeInst(InstBuilder::genStructTyped("Soundfile", sf_type_fields));
 
@@ -610,9 +623,17 @@ void global::init()
     gMathForeignFunctions["copysignf"] = true;
     gMathForeignFunctions["copysign"]  = true;
     gMathForeignFunctions["copysignl"] = true;
+    
+    // internal state during drawing
+    gInverter[0] = boxSeq(boxPar(boxWire(), boxInt(-1)), boxPrim2(sigMul));
+    gInverter[1] = boxSeq(boxPar(boxInt(-1), boxWire()), boxPrim2(sigMul));
+    gInverter[2] = boxSeq(boxPar(boxWire(), boxReal(-1.0)), boxPrim2(sigMul));
+    gInverter[3] = boxSeq(boxPar(boxReal(-1.0), boxWire()), boxPrim2(sigMul));
+    gInverter[4] = boxSeq(boxPar(boxInt(0), boxWire()), boxPrim2(sigSub));
+    gInverter[5] = boxSeq(boxPar(boxReal(0.0), boxWire()), boxPrim2(sigSub));
 }
 
-static string printFloat()
+string global::printFloat()
 {
     switch (gGlobal->gFloatSize) {
         case 1:
@@ -622,7 +643,7 @@ static string printFloat()
         case 3:
             return "-quad ";
         case 4:
-            return "-fp ";
+            return "-fx ";
         default:
             faustassert(false);
             return "";
@@ -643,6 +664,7 @@ void global::printCompilationOptions(stringstream& dst, bool backend)
         dst << "-lang " << gOutputLang << " ";
 #endif
     }
+    if (gInlineArchSwitch) dst << "-i ";
     if (gInPlace) dst << "-inpl ";
     if (gOneSample >= 0) dst << "-os" << gOneSample << " ";
     if (gLightMode) dst << "-light ";
@@ -650,28 +672,40 @@ void global::printCompilationOptions(stringstream& dst, bool backend)
     if (gComputeMix) dst << "-cm ";
     if (gRangeUI) dst << "-rui ";
     if (gMathApprox) dst << "-mapp ";
+    if (gClassName != "mydsp") dst << "-cn " << gClassName << " ";
+    if (gSuperClassName != "dsp") dst << "-scn " << gSuperClassName << " ";
+    if (gProcessName != "process") dst << "-pn " << gProcessName << " ";
     if (gMaskDelayLineThreshold != INT_MAX) dst << "-dtl " << gMaskDelayLineThreshold << " ";
     dst << "-es " << gEnableFlag << " ";
     if (gHasExp10) dst << "-exp10 ";
     if (gSchedulerSwitch) dst << "-sch ";
     if (gOpenMPSwitch) dst << "-omp " << ((gOpenMPLoop) ? "-pl " : "");
+    dst << "-mcd " << gGlobal->gMaxCopyDelay << " ";
+    if (gGlobal->gUIMacroSwitch) dst << "-uim ";
+    dst << printFloat() << "-ftz " << gFTZMode << " ";
     if (gVectorSwitch) {
         dst << "-vec "
             << "-lv " << gVectorLoopVariant << " "
             << "-vs " << gVecSize << " " << ((gFunTaskSwitch) ? "-fun " : "") << ((gGroupTaskSwitch) ? "-g " : "")
-            << ((gDeepFirstSwitch) ? "-dfs " : "") << printFloat() << "-ftz " << gFTZMode << " "
-            << "-mcd " << gGlobal->gMaxCopyDelay;
-    } else {
-        dst << printFloat() << "-ftz " << gFTZMode;
+            << ((gDeepFirstSwitch) ? "-dfs " : "");
     }
-
+  
     // Add 'compile_options' metadata
-    gGlobal->gMetaDataSet[tree("compile_options")].insert(tree("\"" + dst.str() + "\""));
+    string res = dst.str();
+    gGlobal->gMetaDataSet[tree("compile_options")].insert(tree("\"" + res.substr(0, res.size()-1) + "\""));
+}
+
+string global::printCompilationOptions1()
+{
+    stringstream dst;
+    printCompilationOptions(dst, true);
+    string res = dst.str();
+    return res.substr(0, res.size()-1);
 }
 
 void global::initTypeSizeMap()
 {
-    // Init type size table
+    // Init type size table (in bytes)
     gTypeSizeMap[Typed::kFloat]         = gMachineFloatSize;
     gTypeSizeMap[Typed::kFloat_ptr]     = gMachinePtrSize;
     gTypeSizeMap[Typed::kFloat_ptr_ptr] = gMachinePtrSize;
@@ -683,6 +717,18 @@ void global::initTypeSizeMap()
     gTypeSizeMap[Typed::kDouble_ptr_ptr] = gMachinePtrSize;
     gTypeSizeMap[Typed::kDouble_vec]     = gMachineDoubleSize * gVecSize;
     gTypeSizeMap[Typed::kDouble_vec_ptr] = gMachinePtrSize;
+    
+    gTypeSizeMap[Typed::kQuad]         = gMachineQuadSize;
+    gTypeSizeMap[Typed::kQuad_ptr]     = gMachinePtrSize;
+    gTypeSizeMap[Typed::kQuad_ptr_ptr] = gMachinePtrSize;
+    gTypeSizeMap[Typed::kQuad_vec]     = gMachineQuadSize * gVecSize;
+    gTypeSizeMap[Typed::kQuad_vec_ptr] = gMachinePtrSize;
+    
+    gTypeSizeMap[Typed::kFixedPoint]         = gMachineFixedPointSize;
+    gTypeSizeMap[Typed::kFixedPoint_ptr]     = gMachinePtrSize;
+    gTypeSizeMap[Typed::kFixedPoint_ptr_ptr] = gMachinePtrSize;
+    gTypeSizeMap[Typed::kFixedPoint_vec]     = gMachineFixedPointSize * gVecSize;
+    gTypeSizeMap[Typed::kFixedPoint_vec_ptr] = gMachinePtrSize;
 
     gTypeSizeMap[Typed::kInt32]         = gMachineInt32Size;
     gTypeSizeMap[Typed::kInt32_ptr]     = gMachinePtrSize;
@@ -705,8 +751,7 @@ void global::initTypeSizeMap()
     gTypeSizeMap[Typed::kFloatMacro_ptr_ptr] = gMachinePtrSize;
 
     gTypeSizeMap[Typed::kVoid_ptr]     = gMachinePtrSize;
-    gTypeSizeMap[Typed::kVoid_ptr_ptr] = gMachinePtrSize;
-
+  
     gTypeSizeMap[Typed::kObj_ptr]   = gMachinePtrSize;
     gTypeSizeMap[Typed::kSound_ptr] = gMachinePtrSize;
     gTypeSizeMap[Typed::kUint_ptr]  = gMachinePtrSize;
@@ -717,6 +762,25 @@ int global::audioSampleSize()
     return int(pow(2.f, float(gFloatSize + 1)));
 }
 
+bool global::hasForeignFunction(const string& name, const string& inc_file)
+{
+    // LLVM backend can use 'standard' foreign linked functions
+    static vector<std::string> inc_file_list = { "<math.h>", "<cmath>", "<stdlib.h>" };
+    bool is_linkable = (gOutputLang == "llvm") && (find(begin(inc_file_list), end(inc_file_list), inc_file) != inc_file_list.end());
+    
+    bool has_internal_math_ff = ((gOutputLang == "llvm")
+                                 || startWith(gOutputLang, "wast")
+                                 || startWith(gOutputLang, "wasm")
+                                 || (gOutputLang == "interp")
+                                 || startWith(gOutputLang, "soul")
+                                 || (gOutputLang == "dlang")
+                                 || (gOutputLang == "csharp")
+                                 || (gOutputLang == "rust")
+                                 || (gOutputLang == "julia"));
+    
+    return (has_internal_math_ff && (gMathForeignFunctions.find(name) != gMathForeignFunctions.end())) || is_linkable;
+}
+
 BasicTyped* global::genBasicTyped(Typed::VarType type)
 {
     // Possibly force FAUSTFLOAT type (= kFloatMacro) to internal real
@@ -766,7 +830,7 @@ global::~global()
 #ifdef JAVA_BUILD
     JAVAInstVisitor::cleanup();
 #endif
-#ifdef JULIS_BUILD
+#ifdef JULIA_BUILD
     JuliaInstVisitor::cleanup();
 #endif
 #ifdef RUST_BUILD
