@@ -46,30 +46,30 @@ BinOp* gBinOpTable[] = {
 
     new BinOp("+", "add_vec", "add_scal", "add nsw", "fadd", Instruction::Add, Instruction::FAdd, "i32.add", "i64.add",
               "f32.add", "f64.add", WasmOp::I32Add, WasmOp::I64Add, WasmOp::F32Add, WasmOp::F64Add,
-              FBCInstruction::kAddInt, FBCInstruction::kAddReal, &addNode, &isZero, &isZero, 6),
+              FBCInstruction::kAddInt, FBCInstruction::kAddReal, &addNode, &isZero, &isZero, 7),
     new BinOp("-", "sub_vec", "sub_scal", "sub nsw", "fsub", Instruction::Sub, Instruction::FSub, "i32.sub", "i64.sub",
               "f32.sub", "f64.sub", WasmOp::I32Sub, WasmOp::I64Sub, WasmOp::F32Sub, WasmOp::F64Sub,
-              FBCInstruction::kSubInt, FBCInstruction::kSubReal, &subNode, &noNtrl, &isZero, 7),
+              FBCInstruction::kSubInt, FBCInstruction::kSubReal, &subNode, &noNtrl, &isZero, 8),
     new BinOp("*", "mul_vec", "mul_scal", "mul nsw", "fmul", Instruction::Mul, Instruction::FMul, "i32.mul", "i64.mul",
               "f32.mul", "f64.mul", WasmOp::I32Mul, WasmOp::I64Mul, WasmOp::F32Mul, WasmOp::F64Mul,
-              FBCInstruction::kMultInt, FBCInstruction::kMultReal, &mulNode, &isOne, &isOne, 8, isZero, isZero),
+              FBCInstruction::kMultInt, FBCInstruction::kMultReal, &mulNode, &isOne, &isOne, 9, isZero, isZero),
     new BinOp("/", "div_vec", "div_scal", "sdiv", "fdiv", Instruction::SDiv, Instruction::FDiv, "i32.div_s",
               "i64.div_s", "f32.div", "f64.div", WasmOp::I32DivS, WasmOp::I64DivS, WasmOp::F32Div, WasmOp::F64Div,
-              FBCInstruction::kDivInt, FBCInstruction::kDivReal, &divExtendedNode, &noNtrl, &isOne, 10),
+              FBCInstruction::kDivInt, FBCInstruction::kDivReal, &divExtendedNode, &noNtrl, &isOne, 11),
     new BinOp("%", "mod_vec", "mod_scal", "srem", "frem", Instruction::SRem, Instruction::FRem, "i32.rem_s",
               "i64.rem_s", "dummy", "dummy", WasmOp::I32RemS, WasmOp::I64RemS, WasmOp::Dummy, WasmOp::Dummy,
-              FBCInstruction::kRemInt, FBCInstruction::kRemReal, &remNode, &noNtrl, &noNtrl, 9),
+              FBCInstruction::kRemInt, FBCInstruction::kRemReal, &remNode, &noNtrl, &noNtrl, 10),
 
     new BinOp("<<", "shift_left_vec", "shift_left_scal", "", "", Instruction::Shl, Instruction::Shl, "i32.shl",
               "i64.shl", "dummy", "dummy", WasmOp::I32Shl, WasmOp::I64Shl, WasmOp::Dummy, WasmOp::Dummy,
-              FBCInstruction::kLshInt, FBCInstruction::kLshInt, &lshNode, &noNtrl, &isZero, 8),
+              FBCInstruction::kLshInt, FBCInstruction::kLshInt, &lshNode, &noNtrl, &isZero, 6),
     new BinOp(">>", "ashift_right_vec", "ashift_right_scal", "", "", Instruction::AShr, Instruction::AShr, "i32.shr_s",
               "i64.shr_s", "dummy", "dummy", WasmOp::I32ShrS, WasmOp::I64ShrS, WasmOp::Dummy, WasmOp::Dummy,
-              FBCInstruction::kARshInt, FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 8),
+              FBCInstruction::kARshInt, FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 6),
     new BinOp(">>>", "lshift_right_vec", "lshift_right_scal", "", "", Instruction::LShr, Instruction::LShr, "i32.shr_u",
               "i64.shr_u", "dummy", "dummy", WasmOp::I32ShrU, WasmOp::I64ShrU, WasmOp::Dummy, WasmOp::Dummy,
-              FBCInstruction::kLRshInt, FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 8),
-    
+              FBCInstruction::kLRshInt, FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 6),
+
     new BinOp(">", "gt_vec", "gt_scal", "icmp sgt", "fcmp sgt", ICmpInst::ICMP_SGT, FCmpInst::FCMP_OGT, "i32.gt_s",
               "i64.gt_s", "f32.gt", "f64.gt", WasmOp::I32GtS, WasmOp::I64GtS, WasmOp::F32Gt, WasmOp::F64Gt,
               FBCInstruction::kGTInt, FBCInstruction::kGTReal, &gtNode, &noNtrl, &noNtrl, 5),
@@ -84,20 +84,20 @@ BinOp* gBinOpTable[] = {
               FBCInstruction::kLEInt, FBCInstruction::kLEReal, &leNode, &noNtrl, &noNtrl, 5),
     new BinOp("==", "eq_vec", "eq_scal", "icmp eq", "fcmp eq", ICmpInst::ICMP_EQ, FCmpInst::FCMP_OEQ, "i32.eq",
               "i64.eq", "f32.eq", "f64.eq", WasmOp::I32Eq, WasmOp::I64Eq, WasmOp::F32Eq, WasmOp::F64Eq,
-              FBCInstruction::kEQInt, FBCInstruction::kEQReal, &eqNode, &noNtrl, &noNtrl, 5),
+              FBCInstruction::kEQInt, FBCInstruction::kEQReal, &eqNode, &noNtrl, &noNtrl, 4),
     new BinOp("!=", "neq_vec", "neq_scal", "icmp ne", "fcmp ne", ICmpInst::ICMP_NE, FCmpInst::FCMP_ONE, "i32.ne",
               "i64.ne", "f32.ne", "f64.ne", WasmOp::I32Ne, WasmOp::I64Ne, WasmOp::F32Ne, WasmOp::F64Ne,
-              FBCInstruction::kNEInt, FBCInstruction::kNEReal, &neNode, &noNtrl, &noNtrl, 5),
+              FBCInstruction::kNEInt, FBCInstruction::kNEReal, &neNode, &noNtrl, &noNtrl, 4),
 
     new BinOp("&", "and_vec", "and_scal", "and", "and", Instruction::And, Instruction::And, "i32.and", "i64.and",
               "dummy", "dummy", WasmOp::I32And, WasmOp::I64And, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kANDInt,
-              FBCInstruction::kANDInt, &andNode, &isMinusOne, &isMinusOne, 8, isZero, isZero),
+              FBCInstruction::kANDInt, &andNode, &isMinusOne, &isMinusOne, 3, isZero, isZero),
     new BinOp("|", "or_vec", "or_scal", "or", "or", Instruction::Or, Instruction::Or, "i32.or", "i64.or", "dummy",
               "dummy", WasmOp::I32Or, WasmOp::I64Or, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kORInt,
-              FBCInstruction::kORInt, &orNode, &isZero, &isZero, 7),
+              FBCInstruction::kORInt, &orNode, &isZero, &isZero, 1),
     new BinOp("^", "xor_vec", "xor_scal", "xor", "xor", Instruction::Xor, Instruction::Xor, "i32.xor", "i64.xor",
               "dummy", "dummy", WasmOp::I32Xor, WasmOp::I64Xor, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kXORInt,
-              FBCInstruction::kXORInt, &xorNode, &noNtrl, &noNtrl, 8)};
+              FBCInstruction::kXORInt, &xorNode, &noNtrl, &noNtrl, 2)};
 
 #else
 
@@ -105,29 +105,29 @@ BinOp* gBinOpTable[] = {
 
     new BinOp("+", "add_vec", "add_scal", "add nsw", "fadd", 0, 0, "i32.add", "i64.add", "f32.add", "f64.add",
               WasmOp::I32Add, WasmOp::I64Add, WasmOp::F32Add, WasmOp::F64Add, FBCInstruction::kAddInt,
-              FBCInstruction::kAddReal, &addNode, &isZero, &isZero, 6),
+              FBCInstruction::kAddReal, &addNode, &isZero, &isZero, 7),
     new BinOp("-", "sub_vec", "sub_scal", "sub nsw", "fsub", 0, 0, "i32.sub", "i64.sub", "f32.sub", "f64.sub",
               WasmOp::I32Sub, WasmOp::I64Sub, WasmOp::F32Sub, WasmOp::F64Sub, FBCInstruction::kSubInt,
-              FBCInstruction::kSubReal, &subNode, &noNtrl, &isZero, 7),
+              FBCInstruction::kSubReal, &subNode, &noNtrl, &isZero, 8),
     new BinOp("*", "mul_vec", "mul_scal", "mul nsw", "fmul", 0, 0, "i32.mul", "i64.mul", "f32.mul", "f64.mul",
               WasmOp::I32Mul, WasmOp::I64Mul, WasmOp::F32Mul, WasmOp::F64Mul, FBCInstruction::kMultInt,
-              FBCInstruction::kMultReal, &mulNode, &isOne, &isOne, 8, isZero, isZero),
+              FBCInstruction::kMultReal, &mulNode, &isOne, &isOne, 9, isZero, isZero),
     new BinOp("/", "div_vec", "div_scal", "sdiv", "fdiv", 0, 0, "i32.div_s", "i64.div_s", "f32.div", "f64.div",
               WasmOp::I32DivS, WasmOp::I64DivS, WasmOp::F32Div, WasmOp::F64Div, FBCInstruction::kDivInt,
-              FBCInstruction::kDivReal, &divExtendedNode, &noNtrl, &isOne, 10),
+              FBCInstruction::kDivReal, &divExtendedNode, &noNtrl, &isOne, 11),
     new BinOp("%", "mod_vec", "mod_scal", "srem", "frem", 0, 0, "i32.rem_s", "i64.rem_s", "dummy", "dummy",
               WasmOp::I32RemS, WasmOp::I64RemS, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kRemInt,
-              FBCInstruction::kRemReal, &remNode, &noNtrl, &noNtrl, 9),
+              FBCInstruction::kRemReal, &remNode, &noNtrl, &noNtrl, 10),
 
     new BinOp("<<", "shift_left_vec", "shift_left_scal", "", "", 0, 0, "i32.shl", "i64.shl", "dummy", "dummy",
               WasmOp::I32Shl, WasmOp::I64Shl, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kLshInt,
-              FBCInstruction::kLshInt, &lshNode, &noNtrl, &isZero, 8),
+              FBCInstruction::kLshInt, &lshNode, &noNtrl, &isZero, 6),
     new BinOp(">>", "ashift_right_vec", "ashift_right_scal", "", "", 0, 0, "i32.shr_s", "i64.shr_s", "dummy", "dummy",
               WasmOp::I32ShrS, WasmOp::I64ShrS, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kARshInt,
-              FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 8),
+              FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 6),
     new BinOp(">>>", "lshift_right_vec", "lshift_right_scal", "", "", 0, 0, "i32.shr_u", "i64.shr_u", "dummy", "dummy",
               WasmOp::I32ShrU, WasmOp::I64ShrU, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kLRshInt,
-              FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 8),
+              FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 6),
 
     new BinOp(">", "gt_vec", "gt_scal", "icmp sgt", "fcmp sgt", 0, 0, "i32.gt_s", "i64.gt_s", "f32.gt", "f64.gt",
               WasmOp::I32GtS, WasmOp::I64GtS, WasmOp::F32Gt, WasmOp::F64Gt, FBCInstruction::kGTInt,
@@ -143,20 +143,20 @@ BinOp* gBinOpTable[] = {
               FBCInstruction::kLEReal, &leNode, &noNtrl, &noNtrl, 5),
     new BinOp("==", "eq_vec", "eq_scal", "icmp eq", "fcmp eq", 0, 0, "i32.eq", "i64.eq", "f32.eq", "f64.eq",
               WasmOp::I32Eq, WasmOp::I64Eq, WasmOp::F32Eq, WasmOp::F64Eq, FBCInstruction::kEQInt,
-              FBCInstruction::kEQReal, &eqNode, &noNtrl, &noNtrl, 5),
+              FBCInstruction::kEQReal, &eqNode, &noNtrl, &noNtrl, 4),
     new BinOp("!=", "neq_vec", "neq_scal", "icmp ne", "fcmp ne", 0, 0, "i32.ne", "i64.ne", "f32.ne", "f64.ne",
               WasmOp::I32Ne, WasmOp::I64Ne, WasmOp::F32Ne, WasmOp::F64Ne, FBCInstruction::kNEInt,
-              FBCInstruction::kNEReal, &neNode, &noNtrl, &noNtrl, 5),
+              FBCInstruction::kNEReal, &neNode, &noNtrl, &noNtrl, 4),
 
     new BinOp("&", "and_vec", "and_scal", "and", "and", 0, 0, "i32.and", "i64.and", "dummy", "dummy", WasmOp::I32And,
               WasmOp::I64And, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kANDInt, FBCInstruction::kANDInt, &andNode,
-              &isMinusOne, &isMinusOne, 8, isZero, isZero),
+              &isMinusOne, &isMinusOne, 3, isZero, isZero),
     new BinOp("|", "or_vec", "or_scal", "or", "or", 0, 0, "i32.or", "i64.or", "dummy", "dummy", WasmOp::I32Or,
               WasmOp::I64Or, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kORInt, FBCInstruction::kORInt, &orNode,
-              &isZero, &isZero, 7),
+              &isZero, &isZero, 1),
     new BinOp("^", "xor_vec", "xor_scal", "xor", "xor", 0, 0, "i32.xor", "i64.xor", "dummy", "dummy", WasmOp::I32Xor,
               WasmOp::I64Xor, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kXORInt, FBCInstruction::kXORInt, &xorNode,
-              &noNtrl, &noNtrl, 8)};
+              &noNtrl, &noNtrl, 2)};
 
 #endif
 
@@ -182,12 +182,12 @@ BinOp* gBinOpLateqTable[] = {
     new BinOp("\\hiderel{\\ll}", "shift_left_vec", "shift_left_scal", "", "", 0, 0, "i32.shl", "i64.shl", "dummy",
               "dummy", WasmOp::I32Shl, WasmOp::I64Shl, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kLshInt,
               FBCInstruction::kLshInt, &lshNode, &noNtrl, &isZero, 8),
-    new BinOp("\\hiderel{\\gg}", "ashift_right_vec", "ashift_right_scal", "", "", 0, 0, "i32.shr_s", "i64.shr_s", "dummy",
-              "dummy", WasmOp::I32ShrS, WasmOp::I64ShrS, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kARshInt,
-              FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 8),
-    new BinOp("\\hiderel{\\gg}", "lshift_right_vec", "lshift_right_scal", "", "", 0, 0, "i32.shr_u", "i64.shr_u", "dummy",
-              "dummy", WasmOp::I32ShrU, WasmOp::I64ShrU, WasmOp::Dummy, WasmOp::Dummy, FBCInstruction::kLRshInt,
-              FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 8),
+    new BinOp("\\hiderel{\\gg}", "ashift_right_vec", "ashift_right_scal", "", "", 0, 0, "i32.shr_s", "i64.shr_s",
+              "dummy", "dummy", WasmOp::I32ShrS, WasmOp::I64ShrS, WasmOp::Dummy, WasmOp::Dummy,
+              FBCInstruction::kARshInt, FBCInstruction::kARshInt, &arshNode, &noNtrl, &isZero, 8),
+    new BinOp("\\hiderel{\\gg}", "lshift_right_vec", "lshift_right_scal", "", "", 0, 0, "i32.shr_u", "i64.shr_u",
+              "dummy", "dummy", WasmOp::I32ShrU, WasmOp::I64ShrU, WasmOp::Dummy, WasmOp::Dummy,
+              FBCInstruction::kLRshInt, FBCInstruction::kLRshInt, &lrshNode, &noNtrl, &isZero, 8),
 
     new BinOp("\\hiderel{>}", "gt_vec", "gt_scal", "icmp sgt", "fcmp sgt", 0, 0, "i32.gt_s", "i64.gt_s", "f32.gt",
               "f64.gt", WasmOp::I32GtS, WasmOp::I64GtS, WasmOp::F32Gt, WasmOp::F64Gt, FBCInstruction::kGTInt,
